import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { Form, Row, Col, Button, Input, InputNumber, Radio } from 'antd'
import './index.scss'

class ExcelOutColumn extends Component {
  static propTpyes = {
    columnChange: PropTypes.func    // 修改函数
  }

  handleConfirm = () => {
    // 表单提交时检查输入值是否正确
    this.props.form.validateFieldsAndScroll((err, values) => {
      if (!err) {
        this.props.columnChange(values)
        this.props.form.setFieldsValue({
          Column: '',
          Text: '',
          Width: 20
        })
      }
    })
  }

  render() {
    const { getFieldDecorator } = this.props.form
    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
      }
    }

    return (
      <Form {...formItemLayout} className="verify-form">
        <Row gutter={24}>
          <Col span={5}>
            <Form.Item label="字段">
              {getFieldDecorator('Column', {
                initialValue: '',
                rules: [
                  {
                    required: true,
                    message: '请输入字段!'
                  }
                ]
              })(<Input placeholder="" autoComplete="off" />)}
            </Form.Item>
          </Col>
          <Col span={5}>
            <Form.Item label="名称">
              {getFieldDecorator('Text', {
                initialValue: '',
                rules: [
                  {
                    required: true,
                    message: '请输入名称!'
                  }
                ]
              })(<Input placeholder="" autoComplete="off" />)}
            </Form.Item>
          </Col>
          <Col span={5}>
            <Form.Item label="列宽">
              {getFieldDecorator('Width', {
                initialValue: 20,
                rules: [
                  {
                    required: true,
                    message: '请输入列宽!'
                  }
                ]
              })(<InputNumber min={5} max={200} precision={0} />)}
            </Form.Item>
          </Col>
          <Col span={6}>
            <Form.Item label="类型">
              {getFieldDecorator('type', {
                initialValue: 'text'
              })(
                <Radio.Group style={{whiteSpace: 'nowrap'}}>
                  <Radio value="text">文本</Radio>
                  <Radio value="number">数值</Radio>
                  <Radio value="image">图片</Radio>
                </Radio.Group>
              )}
            </Form.Item>
          </Col>
          <Col span={3} className="add">
            <Button onClick={this.handleConfirm} type="primary" className="mk-green">
              添加
            </Button>
          </Col>
        </Row>
      </Form>
    )
  }
}

export default Form.create()(ExcelOutColumn)